pub enum Error {
InvalidName(String),
MissingValue(String),
MissingHelpArg,
InvalidUnicode,
}Expand description
Error types returned by the library.
Variants
InvalidName(String)
Returned when the parser detects an unregistered flag, option, or command name.
MissingValue(String)
Returned when the parser detects an option with a missing value.
MissingHelpArg
Returned when the parser detects a help command with a missing argument.
InvalidUnicode
Returned when the command line arguments are not valid unicode strings.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn exit(self) -> !
pub fn exit(self) -> !
Prints an error message to stderr and exits with a non-zero status code.
Examples found in repository?
examples/command.rs (line 13)
3fn main() {
4 let mut parser = ArgParser::new()
5 .helptext("Usage: foobar...")
6 .version("1.0")
7 .command("boo", ArgParser::new()
8 .helptext("Usage: foobar boo...")
9 .callback(cmd_boo)
10 );
11
12 if let Err(err) = parser.parse() {
13 err.exit();
14 }
15}More examples
examples/basic.rs (line 11)
3fn main() {
4 let mut parser = ArgParser::new()
5 .helptext("Usage: foobar...")
6 .version("1.0")
7 .option("bar b", "default")
8 .flag("foo f");
9
10 if let Err(err) = parser.parse() {
11 err.exit();
12 }
13
14 if parser.found("foo") {
15 println!("Flag --foo/-f found.");
16 }
17
18 println!("Option --bar/-b has value: {}", parser.value("bar"));
19
20 for arg in parser.args {
21 println!("Arg: {}", arg);
22 }
23}Trait Implementations
Sourceimpl Error for Error
impl Error for Error
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()